Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(512)

Unified Diff: components/autofill/core/browser/autofill_data_util.h

Issue 2896263002: [Payments] Changes to validation in the Credit Card editor (Closed)
Patch Set: rebase Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/autofill/core/browser/autofill_data_util.h
diff --git a/components/autofill/core/browser/autofill_data_util.h b/components/autofill/core/browser/autofill_data_util.h
index 4add93c09c16bc1f3a3045280ddc0795d65fd796..2e3d6fcb1a51e17d10f4b4f071dd7ce996b96634 100644
--- a/components/autofill/core/browser/autofill_data_util.h
+++ b/components/autofill/core/browser/autofill_data_util.h
@@ -52,9 +52,10 @@ bool ProfileMatchesFullName(base::StringPiece16 full_name,
const autofill::AutofillProfile& profile);
// Returns the Payment Request API basic card payment spec data for the provided
-// autofill credit card |type|. Will set the type and the icon to "generic" for
-// any unrecognized type.
-const PaymentRequestData& GetPaymentRequestData(const std::string& type);
+// autofill credit card |network|. Will set the network and the icon to
+// "generic" for any unrecognized type.
+const PaymentRequestData& GetPaymentRequestData(
+ const std::string& issuer_network);
// Returns the autofill credit card issuer network string for the provided
// Payment Request API basic card payment spec |basic_card_card_issuer_network|.
« no previous file with comments | « chrome/browser/ui/views/payments/validation_delegate.h ('k') | components/autofill/core/browser/autofill_data_util.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698